Changes
=======

Unreleased
----------

Version 0.5.1
-------------

Released 2024-01-27

- Add Python 3.12 to CI. `#149 <https://github.com/dajiaji/flask-paseto-extended/pull/149>`__
- Usee request_ctx instead of _request_ctx_stack. `#131 <https://github.com/dajiaji/flask-paseto-extended/pull/131>`__
- Add Python 3.12 to tox.ini. `#130 <https://github.com/dajiaji/flask-paseto-extended/pull/130>`__
- Fix .readthedocs.yml. `#129 <https://github.com/dajiaji/flask-paseto-extended/pull/129>`__
- Update dependencies.
    - Bump pyseto to 1.7.8. `#149 <https://github.com/dajiaji/flask-paseto-extended/pull/149>`__
    - Bump Werkzeug to 2.3.8. `#132 <https://github.com/dajiaji/flask-paseto-extended/pull/132>`__
    - Bump Flask-Login to 0.6.3. `#119 <https://github.com/dajiaji/flask-paseto-extended/pull/119>`__
    - Bump urllib3 to 2.0.7. `#114 <https://github.com/dajiaji/flask-paseto-extended/pull/114>`__
- Update dev dependencies.
    - Bump sphinx-autodoc-typehints to 1.25.3. `#148 <https://github.com/dajiaji/flask-paseto-extended/pull/148>`__
    - Bump coverage to 7.4.1. `#147 <https://github.com/dajiaji/flask-paseto-extended/pull/147>`__
    - Bump tox to 4.12.1. `#146 <https://github.com/dajiaji/flask-paseto-extended/pull/146>`__
    - Bump jinja2 to 3.1.3. `#144 <https://github.com/dajiaji/flask-paseto-extended/pull/144>`__
    - Bump pre-commit/flake8 to 7.0.0. `#143 <https://github.com/dajiaji/flask-paseto-extended/pull/143>`__
    - Bump pytest to 7.4.4. `#141 <https://github.com/dajiaji/flask-paseto-extended/pull/141>`__
    - Bump mypy to 1.8.0. `#139 <https://github.com/dajiaji/flask-paseto-extended/pull/139>`__
    - Bump pre-commit/black to 23.12.1. `#136 <https://github.com/dajiaji/flask-paseto-extended/pull/136>`__
    - Bump pre-commit/isort to 5.13.2. `#136 <https://github.com/dajiaji/flask-paseto-extended/pull/136>`__
    - Bump sphinx-rtd-theme to 2.0.0. `#134 <https://github.com/dajiaji/flask-paseto-extended/pull/134>`__
    - Bump actions to v4. `#126 <https://github.com/dajiaji/flask-paseto-extended/pull/126>`__
    - Bump pre-commit to 3.5.0. `#113 <https://github.com/dajiaji/flask-paseto-extended/pull/113>`__
    - Bump pre-commit/pre-commit-hooks to 4.5.0. `#110 <https://github.com/dajiaji/flask-paseto-extended/pull/110>`__

Version 0.5.0
-------------

Released 2023-09-17

- Drop support for Python 3.7. `#94 <https://github.com/dajiaji/flask-paseto-extended/pull/94>`__
- Add SECURITY.md. `#89 <https://github.com/dajiaji/flask-paseto-extended/pull/89>`__
- Use allowlist_externals on tox. `#84 <https://github.com/dajiaji/flask-paseto-extended/pull/84>`__
- Update dependencies.
    - Bump Werkzeug to 2.3.7. `#99 <https://github.com/dajiaji/flask-paseto-extended/pull/99>`__
    - Bump Flask to 2.3.3. `#99 <https://github.com/dajiaji/flask-paseto-extended/pull/99>`__
    - Bump Flask-Login to 0.6.2. `#99 <https://github.com/dajiaji/flask-paseto-extended/pull/99>`__
    - Bump pyseto to 1.7.4. `#99 <https://github.com/dajiaji/flask-paseto-extended/pull/99>`__
- Update dev dependencies.
    - Bump pytest to 7.2.0. `#101 <https://github.com/dajiaji/flask-paseto-extended/pull/101>`__
    - Bump pre-commit/flake8 to 6.1.0. `#100 <https://github.com/dajiaji/flask-paseto-extended/pull/100>`__
    - Bump pre-commit/black to 23.9.1. `#100 <https://github.com/dajiaji/flask-paseto-extended/pull/100>`__
    - Bump pre-commit/blacken-docs to 1.16.0. `#100 <https://github.com/dajiaji/flask-paseto-extended/pull/100>`__
    - Bump sphinx to 7.0.1. `#99 <https://github.com/dajiaji/flask-paseto-extended/pull/99>`__
    - Bump requests to 2.31.0. `#97 <https://github.com/dajiaji/flask-paseto-extended/pull/97>`__
    - Bump certifi to 2023.7.22. `#96 <https://github.com/dajiaji/flask-paseto-extended/pull/96>`__
    - Bump pygments to 2.15.0. `#95 <https://github.com/dajiaji/flask-paseto-extended/pull/95>`__
    - Bump pre-commit/isort to 5.11.4. `#86 <https://github.com/dajiaji/flask-paseto-extended/pull/86>`__
    - Bump tox to 3.28.0. `#85 <https://github.com/dajiaji/flask-paseto-extended/pull/85>`__
    - Bump pre-commit/pre-commit-hooks to 4.4.0. `#78 <https://github.com/dajiaji/flask-paseto-extended/pull/78>`__
    - Bump sphinx-rtd-theme to 1.1.1. `#77 <https://github.com/dajiaji/flask-paseto-extended/pull/77>`__
    - Bump pytest-cov to 4.0.0. `#70 <https://github.com/dajiaji/flask-paseto-extended/pull/70>`__

Version 0.4.2
-------------

Released 2022-08-11

- Update dependencies.
    - Bump pyseto to 1.6.10. `#65 <https://github.com/dajiaji/flask-paseto-extended/pull/65>`__
- Update dev dependencies.
    - Bump pre-commit/flake8 to 5.0.4. `#64 <https://github.com/dajiaji/flask-paseto-extended/pull/64>`__
    - Bump sphinx to 5.1.1. `#62 <https://github.com/dajiaji/flask-paseto-extended/pull/62>`__
    - Bump mypy to 0.971. `#60 <https://github.com/dajiaji/flask-paseto-extended/pull/60>`__
    - Bump pre-commit/black to 22.6.0. `#59 <https://github.com/dajiaji/flask-paseto-extended/pull/59>`__
    - Bump tox to 3.25.1. `#58 <https://github.com/dajiaji/flask-paseto-extended/pull/58>`__
    - Bump pre-commit/pre-commit-hooks to 4.3.0. `#54 <https://github.com/dajiaji/flask-paseto-extended/pull/54>`__
- Drop support for Python3.6. `#57 <https://github.com/dajiaji/flask-paseto-extended/pull/57>`__

Version 0.4.1
-------------

Released 2022-04-09

- Refine pyproject, tox.ini and github actions. `#44 <https://github.com/dajiaji/flask-paseto-extended/pull/44>`__
- Update dependencies.
    - Update mypy requirement from ^0.910 to ^0.942. `#43 <https://github.com/dajiaji/flask-paseto-extended/pull/43>`__
    - Update pre-commit-hooks from 4.0.1 to 4.1.0. `#37 <https://github.com/dajiaji/flask-paseto-extended/pull/37>`__
    - Update pytest requirement from ^5.2 to ^6.2. `#36 <https://github.com/dajiaji/flask-paseto-extended/pull/36>`__

Version 0.4.0
-------------

Released 2021-12-11

- Migrate the project to poetry. `#33 <https://github.com/dajiaji/flask-paseto-extended/pull/33>`__
- Add support for kid. `#32 <https://github.com/dajiaji/flask-paseto-extended/pull/32>`__

Version 0.3.3
-------------

Released 2021-11-24

- Refine README and docstring for Read the Docs. `#29 <https://github.com/dajiaji/flask-paseto-extended/pull/29>`__
- Refine example. `#28 <https://github.com/dajiaji/flask-paseto-extended/pull/28>`__

Version 0.3.2
-------------

Released 2021-11-23

- Fix .readthedocs not to use setup.py. `#27 <https://github.com/dajiaji/flask-paseto-extended/pull/27>`__

Version 0.3.1
-------------

Released 2021-11-23

- Introduce flit for publishing. `#25 <https://github.com/dajiaji/flask-paseto-extended/pull/25>`__

Version 0.3.0
-------------

Released 2021-11-23

- Add PasetoIssuer and PasetoVerifier. `#19 <https://github.com/dajiaji/flask-paseto-extended/pull/19>`__

Version 0.2.0
-------------

Released 2021-10-24

- Refine app.config name for PasetoLoginManager. `#16 <https://github.com/dajiaji/flask-paseto-extended/pull/16>`__
- Add tests for PasetoLoginManager. `#16 <https://github.com/dajiaji/flask-paseto-extended/pull/16>`__
- Rename package name from Flask PASETO Extended to flask-paseto-extended. `#15 <https://github.com/dajiaji/flask-paseto-extended/pull/15>`__
- Add tests for PasetoCookieSessionInterface. `#14 <https://github.com/dajiaji/flask-paseto-extended/pull/14>`__

Version 0.1.1
-------------

Released 2021-10-23

- Activate Read the Docs. `#12 <https://github.com/dajiaji/flask-paseto-extended/pull/12>`__

Version 0.1.0
-------------

Released 2021-10-23

- First public release. `#11 <https://github.com/dajiaji/flask-paseto-extended/pull/11>`__
